@@ -4,7 +4,7 @@ from typing import Union
 
 import pytorch_lightning as pl
 import torch
-import torch.optim as optim
+from torch import optim as optim
 from torch.utils.data import DataLoader
 
 from pl_bolts.losses.self_supervised_learning import FeatureMapContrastiveTask
@@ -13,48 +13,96 @@ from pl_bolts.models.self_supervised.amdim.networks import AMDIMEncoder
 from pl_bolts.utils.self_supervised import torchvision_ssl_encoder
 
 
+def generate_power_seq(lr, nb):
+    half = int(nb / 2)
+    coefs = [2**pow for pow in range(half, -half - 1, -1)]
+    lrs = [lr * coef for coef in coefs]
+    return lrs
+
+
+# CIFAR 10
+LEARNING_RATE_CIFAR = 2e-4
+DATASET_CIFAR10 = {
+    'dataset': 'cifar10',
+    'ndf': 320,
+    'n_rkhs': 1280,
+    'depth': 10,
+    'image_height': 32,
+    'batch_size': 200,
+    'nb_classes': 10,
+    'lr_options': generate_power_seq(LEARNING_RATE_CIFAR, 11),
+}
+
+# stl-10
+LEARNING_RATE_STL = 2e-4
+DATASET_STL10 = {
+    'dataset': 'stl10',
+    'ndf': 192,
+    'n_rkhs': 1536,
+    'depth': 8,
+    'image_height': 64,
+    'batch_size': 200,
+    'nb_classes': 10,
+    'lr_options': generate_power_seq(LEARNING_RATE_STL, 11),
+}
+
+LEARNING_RATE_IMAGENET = 2e-4
+DATASET_IMAGENET2012 = {
+    'dataset': 'imagenet2012',
+    'ndf': 320,
+    'n_rkhs': 2560,
+    'depth': 10,
+    'image_height': 128,
+    'batch_size': 200,
+    'nb_classes': 1000,
+    'lr_options': generate_power_seq(LEARNING_RATE_IMAGENET, 11),
+}
+
+
 class AMDIM(pl.LightningModule):
+    """
+    PyTorch Lightning implementation of
+    `Augmented Multiscale Deep InfoMax (AMDIM) <https://arxiv.org/abs/1906.00910>`_.
+
+    Paper authors: Philip Bachman, R Devon Hjelm, William Buchwalter.
+
+    Model implemented by: `William Falcon <https://github.com/williamFalcon>`_
+
+    This code is adapted to Lightning using the original author repo
+    (`the original repo <https://github.com/Philip-Bachman/amdim-public>`_).
+
+    Example:
+
+        >>> from pl_bolts.models.self_supervised import AMDIM
+        ...
+        >>> model = AMDIM(encoder='resnet18')
+
+    Train::
+
+        trainer = Trainer()
+        trainer.fit(model)
+    """
 
     def __init__(
-            self,
-            datamodule: Union[str, pl.LightningDataModule] = 'cifar10',
-            encoder: Union[str, torch.nn.Module, pl.LightningModule] = 'amdim_encoder',
-            contrastive_task: Union[FeatureMapContrastiveTask] = FeatureMapContrastiveTask('01, 02, 11'),
-            image_channels: int = 3,
-            image_height: int = 32,
-            encoder_feature_dim: int = 320,
-            embedding_fx_dim: int = 1280,
-            conv_block_depth: int = 10,
-            use_bn: bool = False,
-            tclip: int = 20.0,
-            learning_rate: int = 2e-4,
-            data_dir: str = '',
-            num_classes: int = 10,
-            batch_size: int = 200,
-            **kwargs,
+        self,
+        datamodule: Union[str, pl.LightningDataModule] = 'cifar10',
+        encoder: Union[str, torch.nn.Module, pl.LightningModule] = 'amdim_encoder',
+        contrastive_task: Union[FeatureMapContrastiveTask] = FeatureMapContrastiveTask('01, 02, 11'),
+        image_channels: int = 3,
+        image_height: int = 32,
+        encoder_feature_dim: int = 320,
+        embedding_fx_dim: int = 1280,
+        conv_block_depth: int = 10,
+        use_bn: bool = False,
+        tclip: int = 20.0,
+        learning_rate: int = 2e-4,
+        data_dir: str = '',
+        num_classes: int = 10,
+        batch_size: int = 200,
+        num_workers: int = 16,
+        **kwargs,
     ):
         """
-        PyTorch Lightning implementation of
-        `Augmented Multiscale Deep InfoMax (AMDIM) <https://arxiv.org/abs/1906.00910.>`_
-
-        Paper authors: Philip Bachman, R Devon Hjelm, William Buchwalter.
-
-        Model implemented by: `William Falcon <https://github.com/williamFalcon>`_
-
-        This code is adapted to Lightning using the original author repo
-        (`the original repo <https://github.com/Philip-Bachman/amdim-public>`_).
-
-        Example:
-
-            >>> from pl_bolts.models.self_supervised import AMDIM
-            ...
-            >>> model = AMDIM(encoder='resnet18')
-
-        Train::
-
-            trainer = Trainer()
-            trainer.fit(model)
-
         Args:
             datamodule: A LightningDatamodule
             encoder: an encoder string or model
@@ -87,8 +135,9 @@ class AMDIM(pl.LightningModule):
         self.val_split = None
 
     def init_encoder(self):
-        dummy_batch = torch.zeros((2, self.hparams.image_channels, self.hparams.image_height,
-                                   self.hparams.image_height))
+        dummy_batch = torch.zeros(
+            (2, self.hparams.image_channels, self.hparams.image_height, self.hparams.image_height)
+        )
         encoder_name = self.hparams.encoder
 
         if encoder_name == 'amdim_encoder':
@@ -163,10 +212,7 @@ class AMDIM(pl.LightningModule):
         total_loss = unsupervised_loss
 
         tensorboard_logs = {'train_nce_loss': total_loss}
-        result = {
-            'loss': total_loss,
-            'log': tensorboard_logs
-        }
+        result = {'loss': total_loss, 'log': tensorboard_logs}
 
         return result
 
@@ -180,9 +226,7 @@ class AMDIM(pl.LightningModule):
         loss, lgt_reg = self.contrastive_task((r1_x1, r5_x1, r7_x1), (r1_x2, r5_x2, r7_x2))
         unsupervised_loss = loss.sum() + lgt_reg
 
-        result = {
-            'val_nce': unsupervised_loss
-        }
+        result = {'val_nce': unsupervised_loss}
         return result
 
     def validation_epoch_end(self, outputs):
@@ -196,11 +240,7 @@ class AMDIM(pl.LightningModule):
 
     def configure_optimizers(self):
         opt = optim.Adam(
-            params=self.parameters(),
-            lr=self.hparams.learning_rate,
-            betas=(0.8, 0.999),
-            weight_decay=1e-5,
-            eps=1e-7
+            params=self.parameters(), lr=self.hparams.learning_rate, betas=(0.8, 0.999), weight_decay=1e-5, eps=1e-7
         )
 
         # if self.hparams.datamodule in ['cifar10', 'stl10', 'cifar100']:
@@ -220,7 +260,7 @@ class AMDIM(pl.LightningModule):
             batch_size=self.hparams.batch_size,
             pin_memory=True,
             drop_last=True,
-            num_workers=16,
+            num_workers=self.hparams.num_workers,
         )
         return loader
 
@@ -234,7 +274,7 @@ class AMDIM(pl.LightningModule):
             batch_size=self.hparams.batch_size,
             pin_memory=True,
             drop_last=True,
-            num_workers=16,
+            num_workers=self.hparams.num_workers,
         )
         return loader
 
@@ -243,108 +283,7 @@ class AMDIM(pl.LightningModule):
         parser = ArgumentParser(parents=[parent_parser], add_help=False)
         parser.add_argument('--datamodule', type=str, default='cifar10')
 
-        # CIFAR 10
-        cf_root_lr = 2e-4
-        cifar_10 = {
-            'dataset': 'cifar10',
-            'ndf': 320,
-            'n_rkhs': 1280,
-            'depth': 10,
-            'image_height': 32,
-            'batch_size': 200,
-            'nb_classes': 10,
-            'lr_options': [
-                cf_root_lr * 32,
-                cf_root_lr * 16,
-                cf_root_lr * 8,
-                cf_root_lr * 4,
-                cf_root_lr * 2,
-                cf_root_lr,
-                cf_root_lr * 1 / 2,
-                cf_root_lr * 1 / 4,
-                cf_root_lr * 1 / 8,
-                cf_root_lr * 1 / 16,
-                cf_root_lr * 1 / 32,
-            ]
-        }
-
-        # stl-10
-        stl_root_lr = 2e-4
-        stl10 = {
-            'dataset': 'stl10',
-            'ndf': 192,
-            'n_rkhs': 1536,
-            'depth': 8,
-            'image_height': 64,
-            'batch_size': 200,
-            'nb_classes': 10,
-            'lr_options': [
-                stl_root_lr * 32,
-                stl_root_lr * 16,
-                stl_root_lr * 8,
-                stl_root_lr * 4,
-                stl_root_lr * 2,
-                stl_root_lr,
-                stl_root_lr * 1 / 2,
-                stl_root_lr * 1 / 4,
-                stl_root_lr * 1 / 8,
-                stl_root_lr * 1 / 16,
-                stl_root_lr * 1 / 32,
-            ]
-        }
-
-        imagenet_root_lr = 2e-4
-        imagenet2012 = {
-            'dataset': 'imagenet2012',
-            'ndf': 320,
-            'n_rkhs': 2560,
-            'depth': 10,
-            'image_height': 128,
-            'batch_size': 200,
-            'nb_classes': 1000,
-            'lr_options': [
-                imagenet_root_lr * 32,
-                imagenet_root_lr * 16,
-                imagenet_root_lr * 8,
-                imagenet_root_lr * 4,
-                imagenet_root_lr * 2,
-                imagenet_root_lr,
-                imagenet_root_lr * 1 / 2,
-                imagenet_root_lr * 1 / 4,
-                imagenet_root_lr * 1 / 8,
-                imagenet_root_lr * 1 / 16,
-                imagenet_root_lr * 1 / 32,
-            ]
-        }
-
-        imagenet2012_large = {
-            'dataset': 'imagenet2012',
-            'ndf': 320,
-            'n_rkhs': 2560,
-            'depth': 10,
-            'image_height': 128,
-            'batch_size': 200,
-            'nb_classes': 1000,
-            'lr_options': [
-                imagenet_root_lr * 32,
-                imagenet_root_lr * 16,
-                imagenet_root_lr * 8,
-                imagenet_root_lr * 4,
-                imagenet_root_lr * 2,
-                imagenet_root_lr,
-                imagenet_root_lr * 1 / 2,
-                imagenet_root_lr * 1 / 4,
-                imagenet_root_lr * 1 / 8,
-                imagenet_root_lr * 1 / 16,
-                imagenet_root_lr * 1 / 32,
-            ]
-        }
-
-        DATASETS = {
-            'cifar10': cifar_10,
-            'stl10': stl10,
-            'imagenet2012': imagenet2012
-        }
+        DATASETS = {'cifar10': DATASET_CIFAR10, 'stl10': DATASET_STL10, 'imagenet2012': DATASET_IMAGENET2012}
 
         (args, _) = parser.parse_known_args()
         dataset = DATASETS[args.datamodule]
@@ -356,20 +295,27 @@ class AMDIM(pl.LightningModule):
         parser.add_argument('--tclip', type=float, default=20.0, help='soft clipping range for NCE scores')
         parser.add_argument('--use_bn', type=int, default=0)
         parser.add_argument('--encoder_feature_dim', type=int, default=dataset['ndf'], help='feature size for encoder')
-        parser.add_argument('--embedding_fx_dim', type=int, default=dataset['n_rkhs'],
-                            help='number of dimensions in fake RKHS embeddings')
+        parser.add_argument(
+            '--embedding_fx_dim',
+            type=int,
+            default=dataset['n_rkhs'],
+            help='number of dimensions in fake RKHS embeddings'
+        )
         parser.add_argument('--conv_block_depth', type=int, default=dataset['depth'])
         parser.add_argument('--image_height', type=int, default=dataset['image_height'])
 
         # trainin params
-        resnets = ['resnet18', 'resnet34', 'resnet50', 'resnet101', 'resnet152', 'resnext50_32x4d', 'resnext101_32x8d',
-                   'wide_resnet50_2', 'wide_resnet101_2']
-        parser.add_argument('--batch_size', type=int, default=dataset['batch_size'],
-                            help='input batch size (default: 200)')
+        # resnets = ['resnet18', 'resnet34', 'resnet50', 'resnet101', 'resnet152',
+        #            'resnext50_32x4d', 'resnext101_32x8d',
+        #            'wide_resnet50_2', 'wide_resnet101_2']
+        parser.add_argument(
+            '--batch_size', type=int, default=dataset['batch_size'], help='input batch size (default: 200)'
+        )
         parser.add_argument('--learning_rate', type=float, default=0.0002)
 
         # data
         parser.add_argument('--data_dir', default=os.getcwd(), type=str)
+        parser.add_argument('--num_workers', type=int, default=16)
         return parser
 
 
