@@ -1,4 +1,4 @@
-from pl_bolts.models.self_supervised.cpc.cpc_module import CPCV2  # noqa: F401
+from pl_bolts.models.self_supervised.cpc.cpc_module import CPC_v2  # noqa: F401
 from pl_bolts.models.self_supervised.cpc.networks import cpc_resnet50, cpc_resnet101  # noqa: F401
 from pl_bolts.models.self_supervised.cpc.transforms import (  # noqa: F401
     CPCEvalTransformsCIFAR10,
@@ -10,7 +10,7 @@ from pl_bolts.models.self_supervised.cpc.transforms import (  # noqa: F401
 )
 
 __all__ = [
-    "CPCV2",
+    "CPC_v2",
     "cpc_resnet50",
     "cpc_resnet101",
     "CPCEvalTransformsCIFAR10",
