@@ -3,7 +3,7 @@ from argparse import ArgumentParser
 
 import pytorch_lightning as pl
 
-from pl_bolts.models.self_supervised import CPCV2, SSLFineTuner
+from pl_bolts.models.self_supervised import CPC_v2, SSLFineTuner
 from pl_bolts.models.self_supervised.cpc.transforms import (
     CPCEvalTransformsCIFAR10,
     CPCEvalTransformsSTL10,
@@ -25,7 +25,7 @@ def cli_main():  # pragma: no cover
     args = parser.parse_args()
 
     # load the backbone
-    backbone = CPCV2.load_from_checkpoint(args.ckpt_path, strict=False)
+    backbone = CPC_v2.load_from_checkpoint(args.ckpt_path, strict=False)
 
     if args.dataset == 'cifar10':
         dm = CIFAR10DataModule.from_argparse_args(args)
