@@ -4,114 +4,92 @@ CPC V2
 """
 import math
 from argparse import ArgumentParser
-from typing import Union
+from typing import Optional
 
 import pytorch_lightning as pl
 import torch
-import torch.optim as optim
 from pytorch_lightning.utilities import rank_zero_warn
+from torch import optim as optim
 
-from pl_bolts.callbacks.self_supervised import SSLOnlineEvaluator
-from pl_bolts.datamodules import CIFAR10DataModule, STL10DataModule
-from pl_bolts.datamodules.ssl_imagenet_datamodule import SSLImagenetDataModule
+from pl_bolts.datamodules.stl10_datamodule import STL10DataModule
 from pl_bolts.losses.self_supervised_learning import CPCTask
 from pl_bolts.models.self_supervised.cpc.networks import cpc_resnet101
 from pl_bolts.models.self_supervised.cpc.transforms import (
-    CPCTrainTransformsCIFAR10,
     CPCEvalTransformsCIFAR10,
-    CPCTrainTransformsSTL10,
+    CPCEvalTransformsImageNet128,
     CPCEvalTransformsSTL10,
+    CPCTrainTransformsCIFAR10,
     CPCTrainTransformsImageNet128,
-    CPCEvalTransformsImageNet128
+    CPCTrainTransformsSTL10,
 )
 from pl_bolts.utils.pretrained_weights import load_pretrained
 from pl_bolts.utils.self_supervised import torchvision_ssl_encoder
 
-__all__ = [
-    'CPCV2'
-]
+__all__ = ['CPC_v2']
 
 
-class CPCV2(pl.LightningModule):
+class CPC_v2(pl.LightningModule):
 
     def __init__(
-            self,
-            datamodule: pl.LightningDataModule = None,
-            encoder: Union[str, torch.nn.Module, pl.LightningModule] = 'cpc_encoder',
-            patch_size: int = 8,
-            patch_overlap: int = 4,
-            online_ft: int = True,
-            task: str = 'cpc',
-            num_workers: int = 4,
-            learning_rate: int = 1e-4,
-            data_dir: str = '',
-            batch_size: int = 32,
-            pretrained: str = None,
-            **kwargs,
+        self,
+        encoder_name: str = 'cpc_encoder',
+        patch_size: int = 8,
+        patch_overlap: int = 4,
+        online_ft: bool = True,
+        task: str = 'cpc',
+        num_workers: int = 4,
+        num_classes: int = 10,
+        learning_rate: float = 1e-4,
+        pretrained: Optional[str] = None,
+        **kwargs,
     ):
         """
         Args:
-            datamodule: A Datamodule (optional). Otherwise set the dataloaders directly
-            encoder: A string for any of the resnets in torchvision, or the original CPC encoder,
+            encoder_name: A string for any of the resnets in torchvision, or the original CPC encoder,
                 or a custon nn.Module encoder
             patch_size: How big to make the image patches
-            patch_overlap: How much overlap should each patch have.
-            online_ft: Enable a 1024-unit MLP to fine-tune online
+            patch_overlap: How much overlap each patch should have
+            online_ft: If True, enables a 1024-unit MLP to fine-tune online
             task: Which self-supervised task to use ('cpc', 'amdim', etc...)
-            num_workers: num dataloader worksers
-            learning_rate: what learning rate to use
-            data_dir: where to store data
-            batch_size: batch size
+            num_workers: number of dataloader workers
+            num_classes: number of classes
+            learning_rate: learning rate
             pretrained: If true, will use the weights pretrained (using CPC) on Imagenet
         """
 
         super().__init__()
         self.save_hyperparameters()
 
-        self.online_evaluator = self.hparams.online_ft
+        self.online_evaluator = online_ft
 
         if pretrained:
             self.hparams.dataset = pretrained
             self.online_evaluator = True
 
-        # link data
-        if datamodule is None:
-            datamodule = CIFAR10DataModule(
-                self.hparams.data_dir,
-                num_workers=self.hparams.num_workers,
-                batch_size=batch_size
-            )
-            datamodule.train_transforms = CPCTrainTransformsCIFAR10()
-            datamodule.val_transforms = CPCEvalTransformsCIFAR10()
-        self.datamodule = datamodule
-
-        # init encoder
-        self.encoder = encoder
-        if isinstance(encoder, str):
-            self.encoder = self.init_encoder()
+        self.encoder = self.init_encoder()
 
         # info nce loss
-        c, h = self.__compute_final_nb_c(self.hparams.patch_size)
+        c, h = self.__compute_final_nb_c(patch_size)
         self.contrastive_task = CPCTask(num_input_channels=c, target_dim=64, embed_scale=0.1)
 
         self.z_dim = c * h * h
-        self.num_classes = self.datamodule.num_classes
+        self.num_classes = num_classes
 
         if pretrained:
-            self.load_pretrained(encoder)
+            self.load_pretrained(encoder_name)
 
-    def load_pretrained(self, encoder):
+    def load_pretrained(self, encoder_name):
         available_weights = {'resnet18'}
 
-        if encoder in available_weights:
-            load_pretrained(self, f'CPCV2-{encoder}')
-        elif available_weights not in available_weights:
-            rank_zero_warn(f'{encoder} not yet available')
+        if encoder_name in available_weights:
+            load_pretrained(self, f'CPC_v2-{encoder_name}')
+        elif encoder_name not in available_weights:
+            rank_zero_warn(f'{encoder_name} not yet available')
 
     def init_encoder(self):
         dummy_batch = torch.zeros((2, 3, self.hparams.patch_size, self.hparams.patch_size))
 
-        encoder_name = self.hparams.encoder
+        encoder_name = self.hparams.encoder_name
         if encoder_name == 'cpc_encoder':
             return cpc_resnet101(dummy_batch)
         else:
@@ -132,16 +110,16 @@ class CPCV2(pl.LightningModule):
     def __recover_z_shape(self, Z, b):
         # recover shape
         Z = Z.squeeze(-1)
-        nb_feats = int(math.sqrt(Z.size(0) // b))
+        nb_patches = int(math.sqrt(Z.size(0) // b))
         Z = Z.view(b, -1, Z.size(1))
         Z = Z.permute(0, 2, 1).contiguous()
-        Z = Z.view(b, -1, nb_feats, nb_feats)
+        Z = Z.view(b, -1, nb_patches, nb_patches)
 
         return Z
 
     def forward(self, img_1):
         # put all patches on the batch dim for simultaneous processing
-        b, p, c, w, h = img_1.size()
+        b, _, c, w, h = img_1.size()
         img_1 = img_1.view(-1, c, w, h)
 
         # Z are the latent vars
@@ -161,23 +139,21 @@ class CPCV2(pl.LightningModule):
         nce_loss = self.shared_step(batch)
 
         # result
-        result = pl.TrainResult(nce_loss)
-        result.log('train_nce_loss', nce_loss)
-        return result
+        self.log('train_nce_loss', nce_loss)
+        return nce_loss
 
     def validation_step(self, batch, batch_nb):
         # calculate loss
         nce_loss = self.shared_step(batch)
 
         # result
-        result = pl.EvalResult(checkpoint_on=nce_loss)
-        result.log('val_nce', nce_loss, prog_bar=True)
-        return result
+        self.log('val_nce', nce_loss, prog_bar=True)
+        return nce_loss
 
     def shared_step(self, batch):
         if isinstance(self.datamodule, STL10DataModule):
-            unlabeled_batch = batch[0]
-            batch = unlabeled_batch
+            # unlabeled batch
+            batch = batch[0]
 
         img_1, y = batch
 
@@ -195,7 +171,7 @@ class CPCV2(pl.LightningModule):
             lr=self.hparams.learning_rate,
             betas=(0.8, 0.999),
             weight_decay=1e-5,
-            eps=1e-7
+            eps=1e-7,
         )
 
         # if self.hparams.dataset in ['cifar10', 'stl10']:
@@ -207,43 +183,46 @@ class CPCV2(pl.LightningModule):
 
     @staticmethod
     def add_model_specific_args(parent_parser):
+        possible_resnets = [
+            'resnet18',
+            'resnet34',
+            'resnet50',
+            'resnet101',
+            'resnet152',
+            'resnext50_32x4d',
+            'resnext101_32x8d',
+            'wide_resnet50_2',
+            'wide_resnet101_2',
+        ]
         parser = ArgumentParser(parents=[parent_parser], add_help=False)
         parser.add_argument('--online_ft', action='store_true')
         parser.add_argument('--task', type=str, default='cpc')
-
-        possible_resnets = [
-            'resnet18', 'resnet34', 'resnet50', 'resnet101', 'resnet152',
-            'resnext50_32x4d', 'resnext101_32x8d', 'wide_resnet50_2', 'wide_resnet101_2'
-        ]
-        parser.add_argument('--encoder', default='cpc_encoder', type=str)
-
-        # training params
-        parser.add_argument('--batch_size', type=int, default=128)
-
+        parser.add_argument('--encoder', default='cpc_encoder', type=str, choices=possible_resnets)
         # cifar10: 1e-5, stl10: 3e-5, imagenet: 4e-4
         parser.add_argument('--learning_rate', type=float, default=1e-5)
 
-        # data
-        parser.add_argument('--dataset', default='cifar10', type=str)
-        parser.add_argument('--data_dir', default='.', type=str)
-        parser.add_argument('--meta_dir', default='.', type=str, help='path to meta.bin for imagenet')
-        parser.add_argument('--num_workers', default=8, type=int)
-
         return parser
 
 
 def cli_main():
+    from pl_bolts.callbacks.ssl_online import SSLOnlineEvaluator
+    from pl_bolts.datamodules import CIFAR10DataModule
+    from pl_bolts.datamodules.ssl_imagenet_datamodule import SSLImagenetDataModule
+
     pl.seed_everything(1234)
     parser = ArgumentParser()
     parser = pl.Trainer.add_argparse_args(parser)
-    parser = CPCV2.add_model_specific_args(parser)
+    parser = CPC_v2.add_model_specific_args(parser)
+    parser.add_argument('--dataset', default='cifar10', type=str)
+    parser.add_argument('--data_dir', default='.', type=str)
+    parser.add_argument('--meta_dir', default='.', type=str, help='path to meta.bin for imagenet')
+    parser.add_argument('--num_workers', default=8, type=int)
+    parser.add_argument('--hidden_mlp', default=2048, type=int, help='hidden layer dimension in projection head')
+    parser.add_argument('--batch_size', type=int, default=128)
 
     args = parser.parse_args()
-    args.online_ft = True
 
     datamodule = None
-
-    online_evaluator = SSLOnlineEvaluator()
     if args.dataset == 'cifar10':
         datamodule = CIFAR10DataModule.from_argparse_args(args)
         datamodule.train_transforms = CPCTrainTransformsCIFAR10()
@@ -258,6 +237,20 @@ def cli_main():
         datamodule.val_transforms = CPCEvalTransformsSTL10()
         args.patch_size = 16
 
+    elif args.dataset == 'imagenet2012':
+        datamodule = SSLImagenetDataModule.from_argparse_args(args)
+        datamodule.train_transforms = CPCTrainTransformsImageNet128()
+        datamodule.val_transforms = CPCEvalTransformsImageNet128()
+        args.patch_size = 32
+
+    online_evaluator = SSLOnlineEvaluator(
+        drop_p=0.,
+        hidden_dim=None,
+        z_dim=args.hidden_mlp,
+        num_classes=datamodule.num_classes,
+        dataset=args.dataset,
+    )
+    if args.dataset == 'stl10':
         # 16 GB RAM - 64
         # 32 GB RAM - 144
         args.batch_size = 144
@@ -270,15 +263,9 @@ def cli_main():
 
         online_evaluator.to_device = to_device
 
-    elif args.dataset == 'imagenet2012':
-        datamodule = SSLImagenetDataModule.from_argparse_args(args)
-        datamodule.train_transforms = CPCTrainTransformsImageNet128()
-        datamodule.val_transforms = CPCEvalTransformsImageNet128()
-        args.patch_size = 32
-
-    model = CPCV2(**vars(args), datamodule=datamodule)
+    model = CPC_v2(**vars(args))
     trainer = pl.Trainer.from_argparse_args(args, callbacks=[online_evaluator])
-    trainer.fit(model)
+    trainer.fit(model, datamodule=datamodule)
 
 
 if __name__ == '__main__':
