@@ -2,6 +2,7 @@ from torch import nn
 
 
 class SSLEvaluator(nn.Module):
+
     def __init__(self, n_input, n_classes, n_hidden=512, p=0.1):
         super().__init__()
         self.n_input = n_input
@@ -12,7 +13,8 @@ class SSLEvaluator(nn.Module):
             self.block_forward = nn.Sequential(
                 Flatten(),
                 nn.Dropout(p=p),
-                nn.Linear(n_input, n_classes, bias=True)
+                nn.Linear(n_input, n_classes, bias=True),
+                nn.Softmax(),
             )
         else:
             # use simple MLP classifier
@@ -23,7 +25,8 @@ class SSLEvaluator(nn.Module):
                 nn.BatchNorm1d(n_hidden),
                 nn.ReLU(inplace=True),
                 nn.Dropout(p=p),
-                nn.Linear(n_hidden, n_classes, bias=True)
+                nn.Linear(n_hidden, n_classes, bias=True),
+                nn.Softmax(),
             )
 
     def forward(self, x):
@@ -32,6 +35,7 @@ class SSLEvaluator(nn.Module):
 
 
 class Flatten(nn.Module):
+
     def __init__(self):
         super(Flatten, self).__init__()
 
