@@ -1,29 +1,43 @@
 import random
-from warnings import warn
-from pl_bolts.transforms.dataset_normalizations import \
-    imagenet_normalization, cifar10_normalization, stl10_normalization
 
-try:
-    from PIL import ImageFilter
+from pl_bolts.transforms.dataset_normalizations import (
+    cifar10_normalization,
+    imagenet_normalization,
+    stl10_normalization,
+)
+from pl_bolts.utils import _PIL_AVAILABLE, _TORCHVISION_AVAILABLE
+from pl_bolts.utils.warnings import warn_missing_pkg
+
+if _TORCHVISION_AVAILABLE:
     from torchvision import transforms
-except ImportError:
-    warn('You want to use `torchvision` which is not installed yet,'  # pragma: no-cover
-                      ' install it with `pip install torchvision`.')
+else:  # pragma: no cover
+    warn_missing_pkg('torchvision')
+
+if _PIL_AVAILABLE:
+    from PIL import ImageFilter
+else:  # pragma: no cover
+    warn_missing_pkg('PIL', pypi_name='Pillow')
 
 
 class Moco2TrainCIFAR10Transforms:
     """
     Moco 2 augmentation:
     https://arxiv.org/pdf/2003.04297.pdf
-
     """
-    def __init__(self, height=32):
+
+    def __init__(self, height: int = 32):
+        if not _TORCHVISION_AVAILABLE:  # pragma: no cover
+            raise ModuleNotFoundError('You want to use `transforms` from `torchvision` which is not installed yet.')
+
         # image augmentation functions
         self.train_transform = transforms.Compose([
             transforms.RandomResizedCrop(height, scale=(0.2, 1.)),
-            transforms.RandomApply([
-                transforms.ColorJitter(0.4, 0.4, 0.4, 0.1)  # not strengthened
-            ], p=0.8),
+            transforms.RandomApply(
+                [
+                    transforms.ColorJitter(0.4, 0.4, 0.4, 0.1)  # not strengthened
+                ],
+                p=0.8
+            ),
             transforms.RandomGrayscale(p=0.2),
             transforms.RandomApply([GaussianBlur([.1, 2.])], p=0.5),
             transforms.RandomHorizontalFlip(),
@@ -41,9 +55,12 @@ class Moco2EvalCIFAR10Transforms:
     """
     Moco 2 augmentation:
     https://arxiv.org/pdf/2003.04297.pdf
-
     """
-    def __init__(self, height=32):
+
+    def __init__(self, height: int = 32):
+        if not _TORCHVISION_AVAILABLE:  # pragma: no cover
+            raise ModuleNotFoundError('You want to use `transforms` from `torchvision` which is not installed yet.')
+
         self.test_transform = transforms.Compose([
             transforms.Resize(height + 12),
             transforms.CenterCrop(height),
@@ -62,14 +79,20 @@ class Moco2TrainSTL10Transforms:
     Moco 2 augmentation:
     https://arxiv.org/pdf/2003.04297.pdf
     """
-    def __init__(self, height=64):
+
+    def __init__(self, height: int = 64):
+        if not _TORCHVISION_AVAILABLE:  # pragma: no cover
+            raise ModuleNotFoundError('You want to use `transforms` from `torchvision` which is not installed yet.')
 
         # image augmentation functions
         self.train_transform = transforms.Compose([
             transforms.RandomResizedCrop(height, scale=(0.2, 1.)),
-            transforms.RandomApply([
-                transforms.ColorJitter(0.4, 0.4, 0.4, 0.1)  # not strengthened
-            ], p=0.8),
+            transforms.RandomApply(
+                [
+                    transforms.ColorJitter(0.4, 0.4, 0.4, 0.1)  # not strengthened
+                ],
+                p=0.8
+            ),
             transforms.RandomGrayscale(p=0.2),
             transforms.RandomApply([GaussianBlur([.1, 2.])], p=0.5),
             transforms.RandomHorizontalFlip(),
@@ -88,7 +111,11 @@ class Moco2EvalSTL10Transforms:
     Moco 2 augmentation:
     https://arxiv.org/pdf/2003.04297.pdf
     """
-    def __init__(self, height=64):
+
+    def __init__(self, height: int = 64):
+        if not _TORCHVISION_AVAILABLE:  # pragma: no cover
+            raise ModuleNotFoundError('You want to use `transforms` from `torchvision` which is not installed yet.')
+
         self.test_augmentation = transforms.Compose([
             transforms.Resize(height + 11),
             transforms.CenterCrop(height),
@@ -109,13 +136,19 @@ class Moco2TrainImagenetTransforms:
 
     """
 
-    def __init__(self, height=128):
+    def __init__(self, height: int = 128):
+        if not _TORCHVISION_AVAILABLE:  # pragma: no cover
+            raise ModuleNotFoundError('You want to use `transforms` from `torchvision` which is not installed yet.')
+
         # image augmentation functions
         self.train_transform = transforms.Compose([
             transforms.RandomResizedCrop(height, scale=(0.2, 1.)),
-            transforms.RandomApply([
-                transforms.ColorJitter(0.4, 0.4, 0.4, 0.1)  # not strengthened
-            ], p=0.8),
+            transforms.RandomApply(
+                [
+                    transforms.ColorJitter(0.4, 0.4, 0.4, 0.1)  # not strengthened
+                ],
+                p=0.8
+            ),
             transforms.RandomGrayscale(p=0.2),
             transforms.RandomApply([GaussianBlur([.1, 2.])], p=0.5),
             transforms.RandomHorizontalFlip(),
@@ -133,9 +166,12 @@ class Moco2EvalImagenetTransforms:
     """
     Moco 2 augmentation:
     https://arxiv.org/pdf/2003.04297.pdf
-
     """
-    def __init__(self, height=128):
+
+    def __init__(self, height: int = 128):
+        if not _TORCHVISION_AVAILABLE:  # pragma: no cover
+            raise ModuleNotFoundError('You want to use `transforms` from `torchvision` which is not installed yet.')
+
         self.test_transform = transforms.Compose([
             transforms.Resize(height + 32),
             transforms.CenterCrop(height),
@@ -153,6 +189,10 @@ class GaussianBlur(object):
     """Gaussian blur augmentation in SimCLR https://arxiv.org/abs/2002.05709"""
 
     def __init__(self, sigma=(0.1, 2.0)):
+        if not _PIL_AVAILABLE:  # pragma: no cover
+            raise ModuleNotFoundError(
+                'You want to use `Pillow` which is not installed yet, install it with `pip install Pillow`.'
+            )
         self.sigma = sigma
 
     def __call__(self, x):
