@@ -1,9 +1,10 @@
 import pytorch_lightning as pl
 import torch
-import torch.nn as nn
+from torch import nn as nn
 
 
 class Block(nn.Module):
+
     def __init__(self, embed_dim, heads):
         super(Block, self).__init__()
         self.ln_1 = nn.LayerNorm(embed_dim)
@@ -16,9 +17,7 @@ class Block(nn.Module):
         )
 
     def forward(self, x):
-        attn_mask = torch.full(
-            (len(x), len(x)), -float("Inf"), device=x.device, dtype=x.dtype
-        )
+        attn_mask = torch.full((len(x), len(x)), -float("Inf"), device=x.device, dtype=x.dtype)
         attn_mask = torch.triu(attn_mask, diagonal=1)
 
         x = self.ln_1(x)
@@ -30,6 +29,28 @@ class Block(nn.Module):
 
 
 class GPT2(pl.LightningModule):
+    """
+    GPT-2 from `language Models are Unsupervised Multitask Learners <https://d4mucfpksywv.cloudfront.net/
+    better-language-models/language-models.pdf>`_
+
+    Paper by:  Alec Radford, Jeffrey Wu, Rewon Child, David Luan, Dario Amodei, Ilya Sutskever
+
+    Implementation contributed by:
+
+        - `Teddy Koker <https://github.com/teddykoker>`_
+
+    Example::
+
+        from pl_bolts.models.vision import GPT2
+
+        seq_len = 17
+        batch_size = 32
+        vocab_size = 16
+        x = torch.randint(0, vocab_size, (seq_len, batch_size))
+        model = GPT2(embed_dim=32, heads=2, layers=2, num_positions=seq_len, vocab_size=vocab_size, num_classes=4)
+        results = model(x)
+    """
+
     def __init__(
         self,
         embed_dim: int,
@@ -39,27 +60,6 @@ class GPT2(pl.LightningModule):
         vocab_size: int,
         num_classes: int,
     ):
-        """
-        GPT-2 from `language Models are Unsupervised Multitask Learners <https://d4mucfpksywv.cloudfront.net/
-        better-language-models/language-models.pdf>`_
-
-        Paper by:  Alec Radford, Jeffrey Wu, Rewon Child, David Luan, Dario Amodei, Ilya Sutskever
-
-        Implementation contributed by:
-
-            - `Teddy Koker <https://github.com/teddykoker>`_
-
-        Example::
-
-            from pl_bolts.models import GPT2
-
-            seq_len = 17
-            batch_size = 32
-            vocab_size = 16
-            x = torch.randint(0, vocab_size, (seq_len, batch_size))
-            model = GPT2(embed_dim=32, heads=2, layers=2, num_positions=seq_len, vocab_size=vocab_size, num_classes=4)
-            results = model(x)
-        """
         super(GPT2, self).__init__()
         self.save_hyperparameters()
 
@@ -72,12 +72,8 @@ class GPT2(pl.LightningModule):
         nn.init.normal_(self.sos)
 
     def _init_embeddings(self):
-        self.token_embeddings = nn.Embedding(
-            self.hparams.vocab_size, self.hparams.embed_dim
-        )
-        self.position_embeddings = nn.Embedding(
-            self.hparams.num_positions, self.hparams.embed_dim
-        )
+        self.token_embeddings = nn.Embedding(self.hparams.vocab_size, self.hparams.embed_dim)
+        self.position_embeddings = nn.Embedding(self.hparams.num_positions, self.hparams.embed_dim)
 
     def _init_layers(self):
         self.layers = nn.ModuleList()
@@ -85,9 +81,7 @@ class GPT2(pl.LightningModule):
             self.layers.append(Block(self.hparams.embed_dim, self.hparams.heads))
 
         self.ln_f = nn.LayerNorm(self.hparams.embed_dim)
-        self.head = nn.Linear(
-            self.hparams.embed_dim, self.hparams.vocab_size, bias=False
-        )
+        self.head = nn.Linear(self.hparams.embed_dim, self.hparams.vocab_size, bias=False)
         self.clf_head = nn.Linear(self.hparams.embed_dim, self.hparams.num_classes)
 
     def forward(self, x, classify=False):
